import { View } from '@tarojs/components'
import React, { useCallback, memo, useEffect, useMemo, useRef, useState, ReactNode } from 'react'
import styles from "./index.module.scss"
import classnames from "classnames";
import Taro, { usePullDownRefresh, useRouter, useDidShow } from '@tarojs/taro';
import AdvanceOrderState from './components/advanceOrderState'
import AddressDetailBox from './components/addressDetailBox'
import Remark from '@/components/textareaEnhance'
import Popup from '@/components/popup'
import BottomBtns from '@/components/BottomBtns';
import BottomApply from './components/BottomApply';
import { debounce } from '@/common/util'
import OfflinePay from '../order/components/offlinePay'
import OrderState from './components/orderState'
import {
    mpsaleOrder,
    mpsaleOrderput,
    mpshoppingCartproductColorlist,
    orderPaymentorderPaymentMethodInfo,
    orderPaymentpreCollectOrderorderPaymentMethodInfo,
    orderPaymentorderPaymentSubmission,
    orderPaymentpreCollectOrderorderPaymentSubmission,
    mpsaleOrdercancel,
    GetPayCode,
    mpsaleOrderaddress,
    mpsaleOrdershipmentMode,
    mpsaleOrderreceive
} from '@/api/order'
import { alert, goLink } from '@/common/common'
import { formatPriceDiv, formatDateTime, formatWeightDiv } from '@/common/format'
import PayPopup from '../order/components/PayPopup'
import IconFont from '@/components/iconfont/iconfont'
import { PAY_H5_CODE_URL } from '@/common/constant'
export default () => {
    const router = useRouter()
    // useEffect(() => {
    //     getDetail()
    // }, [])
    useDidShow(() => {
        getDetail()
    })
    //页面下拉刷新
    usePullDownRefresh(() => {
        getDetail()
    })


    //收货方法,1:自提，2物流
    const [receivingStatus, setReceivingStatus] = useState(null)
    //切换自提或者物流
    const { fetchData: selectFetch } = mpsaleOrdershipmentMode()
    const onReceivingStatus = debounce(async (e, value) => {
        if (infoObj.status === 8 || infoObj.status === 9 || infoObj.status === 4 || infoObj.status === 5 || infoObj.status === 3 || infoObj.status === 11) {
            alert.error('不允许更改')
            return false
        }
        e.stopPropagation()
        if (receivingStatus === value) {
            alert.error('不能选择相同的方式')
            return false
        }
        Taro.showLoading({
            title: '请稍等...',
            mask: true
        })
        const res = await selectFetch({ id: Number(infoObj.id), shipment_mode: value })
        if (res.msg === 'success') {
            Taro.hideLoading()
            Taro.showToast({
                title: '成功',
                icon: 'success'
            })
            setReceivingStatus(value)
            getDetail()
        } else {
            if (res.data.code == 70029) {
                Taro.hideLoading()
                Taro.showToast({
                    title: res.msg,
                    icon: 'error'
                })
            } else {
                Taro.hideLoading()
                Taro.showToast({
                    title: '请先去新增地址',
                    icon: 'error'
                })
            }
        }
    }, 300)

    const { fetchData: infoFetch } = mpsaleOrder()
    const [infoObj, setInfoObj] = useState<any>({})
    //获取订单详情
    const getDetail = async () => {
        Taro.showLoading({
            title: '加载中...',
            mask: true
        })
        const res = await infoFetch({ id: router.params.id })
        setInfoObj(res.data)
        orderMsg.map(it => {
            if (it.leftTitle === '订单编号：') {
                it.rightTitle = res.data.order_no
            }
            if (it.leftTitle === '创建时间：') {
                it.rightTitle = formatDateTime(res.data.create_time)
            }
            if (it.leftTitle === '发货时间：') {
                it.rightTitle = formatDateTime(res.data.delivery_time)
            }
            if (it.leftTitle === '业务员：') {
                it.rightTitle = res.data.sale_user_name
            }
        })
        setOrderMsg([...orderMsg])
        setReceivingStatus(res.data.shipment_mode)
        // 小程序提供的api，通知页面停止下拉刷新效果
        Taro.stopPullDownRefresh();
        Taro.hideLoading()
    }
    //复制功能
    const clipboardData = () => {
        Taro.setClipboardData({
            data: infoObj?.order_no || '',
            success: function (res) {
                Taro.showToast({
                    icon: 'none',
                    title: '复制成功',
                })
            },
        })
    }

    // useEffect(() => {
    //     setReceivingStatus(receivingStatus)
    // }, [receivingStatus])
    //订单信息文字数组
    const [orderMsg, setOrderMsg] = useState<any[]>([
        {
            leftTitle: '订单编号：',
            rightTitle: '------',
            showBtn: true
        },
        {
            leftTitle: '创建时间：',
            rightTitle: '------',
        },
        {
            leftTitle: '发货时间：',
            rightTitle: '------',
        },
        {
            leftTitle: '业务员：',
            rightTitle: '------',
        }
    ])

    //备注操作
    const [showDesc, setShowDesc] = useState(false)
    const { fetchData: remarkFetch } = mpsaleOrderput()
    const getRemark = async () => {
        const res = await remarkFetch({ remark: infoObj.remark, id: Number(router.params.id) })
        if (res.msg === 'success') {
            Taro.showToast({
                title: '成功',
                icon: 'success'
            })
            setShowDesc(false)
            getDetail()
        }
    }

    //更多按钮查看操作
    const [showMore, setShowMore] = useState(false)

    //刷新页面
    const refresh = useCallback(() => {
        alert.loading('刷新中')
        getDetail()
    }, [])

    const { fetchData: cancelFetch } = mpsaleOrdercancel()
    //取消订单
    const cancle = async (e, item) => {
        e.stopPropagation();
        Taro.showModal({
            content: "确定要取消吗？",
            confirmText: "确认",
            cancelText: "取消",
            success: async function (res) {
                if (res.confirm) {
                    Taro.showLoading({
                        title: '请稍等...',
                        mask: true
                    })
                    const res = await cancelFetch({ id: item.id })
                    if (res.msg === 'success') {
                        Taro.showToast({
                            title: '取消成功'
                        })
                        Taro.hideLoading()
                        getDetail()
                    } else {
                        Taro.showToast({
                            title: res.msg,
                            icon: 'error'
                        })
                    }
                }
            }
        })
    }
    //再次购买
    const { fetchData: buyFetch } = mpshoppingCartproductColorlist()
    const nextBuy = async (e, item) => {
        e.stopPropagation();
        Taro.showLoading({
            title: '请稍等...',
            mask: true
        })
        let arr: any = []
        item.product_list.forEach(item => {
            item.product_colors.forEach(it => {
                arr.push({
                    length: it.length,
                    roll: it.roll,
                    product_color_id: it.id
                })
            })
        })
        let query = {
            purchaser_id: item.purchaser_id,
            sale_mode: item.sale_mode,
            color_list: arr
        }
        const res = await buyFetch(query)
        if (res.msg === 'success') {
            Taro.showToast({
                title: '加入购物车成功!'
            })
            Taro.hideLoading()
            getDetail()
        } else {
            Taro.showToast({
                title: res.msg,
                icon: 'error'
            })
        }
    }
    //去支付逻辑
    const { fetchData: infoOneFetch } = orderPaymentorderPaymentMethodInfo()
    const { fetchData: infoTwoFetch } = orderPaymentpreCollectOrderorderPaymentMethodInfo()
    const [payList, setPayList] = useState<any[]>([
        {
            id: 2,
            iconfont: "icon-yufukuan1",
            name: "预存款",
            fonts: "可用额度 ",
            money: "",
            isCheck: false,
        },
        {
            id: 5,
            iconfont: "icon-xianxiahuizong",
            name: "货到付款",
            fonts: "发货后3天内付款",
            isCheck: false,
            money: "",
        },
        {
            id: 3,
            iconfont: "icon-xianxiahuizong",
            name: "x天账期",
            fonts: "可用额度 ",
            money: "",
            isCheck: false,
        },
        {
            iconfont: "icon-yue",
            name: "线下汇款",
        },
        {
            iconfont: "icon-saomiao",
            name: "扫码支付",
        },
    ])
    const toPay = async (e, item) => {
        e.stopPropagation();

        if (item.status !== 10) {
            let res = await infoOneFetch({ id: item.should_collect_order_id })
            payList.map((item) => {
                if (item.id === 3) {
                    item.name = `${res.data.account_period}天账期`;
                    item.fonts = `可用额度${formatPriceDiv(
                        res.data.account_period_credit_available_line
                    ).toLocaleString()}`;
                }
                if (item.id === 2) {
                    item.fonts = `可用额度${formatPriceDiv(
                        res.data.advance_deposit_balance
                    ).toLocaleString()}`;
                }
                return item;
            });
            setPayList([...payList])
            if (item.is_shipper_picks_up) {
                const obj = payList.filter((item) => {
                    return item.id === 6;
                });
                console.log(obj, "456456");
                if (obj.length === 0) {
                    payList.unshift({
                        id: 6,
                        iconfont: "icon-xianxiahuizong",
                        name: "货主自提",
                        fonts: "",
                        money: "",
                        isCheck: false,
                    });
                    setPayList([...payList])
                }
            }
        } else {
            let res = await infoTwoFetch({ id: item.pre_collect_order_id })
            const arr: any = [];
            arr.push(
                {
                    id: 2,
                    iconfont: "icon-yufukuan1",
                    name: "预存款",
                    fonts: `可用额度${formatPriceDiv(
                        res.data.advance_deposit_balance
                    ).toLocaleString()}`,
                    money: "",
                    isCheck: false,
                },
                {
                    iconfont: "icon-yue",
                    name: "线下汇款",
                },
                {
                    iconfont: "icon-saomiao",
                    name: "扫码支付",
                }
            );
            if (item.is_shipper_picks_up) {
                const obj = arr.filter((item) => {
                    return item.id === 6;
                });
                if (obj.length === 0) {
                    arr.unshift({
                        id: 6,
                        iconfont: "icon-xianxiahuizong",
                        name: "货主自提",
                        fonts: "",
                        money: "",
                        isCheck: false,
                    });
                }
            }
            setPayList([...arr])
        }
        setShowSide(true)
        setTitle('待支付款项')
        setShowPay(true)
    }

    //选择支付方式
    const clickItem = (item) => {
        if (item.name === '扫码支付') { handScanpay() }
        if (item.name === '线下汇款') { setShowOffine(true) }
        payList.map(it => {
            if (item.id === it.id) {
                it.checked = true
            } else {
                it.checked = false
            }
            return it
        })
        setPayList([...payList])
    }


    //扫码支付
    const [showSide, setShowSide] = useState(true)
    const [title, setTitle] = useState('')
    const [picUrl, setPicUrl] = useState('')
    const { fetchData: payFetch } = GetPayCode()
    const handScanpay = async () => {
        const list: any = [];
        infoObj.product_list.forEach((item) => {
            item.product_colors.forEach((it) => {
                list.push({
                    product_code: item.code,
                    product_name: item.name,
                    product_color_code: it.product_color_code,
                    product_color_name: it.product_color_name,
                    num: it.roll.toString(),
                    weight: formatWeightDiv(it.actual_weight).toString(),
                    sale_price: (it.sale_price / 100).toString(),
                    total_price:
                        it.total_sale_price !== 0
                            ? (it.total_sale_price / 100).toString()
                            : (it.estimate_amount / 100).toString(),
                    length: (it.length / 100).toString(),
                    weight_error: formatWeightDiv(it.weight_error).toString(),
                });
            });
        });
        const query = {
            list: list,
            title: "面料销售电子确认单",
            show_qrcode: true,
            show_barcode: true,
            show_wait_pay_amount: true,
            order_type: infoObj.sale_mode_name,
            shipment_mode: infoObj.shipment_mode_name,
            company: infoObj.title_purchaser_name,
            sale_user: infoObj.sale_user_name,
            order_created_time: formatDateTime(infoObj.create_time),
            order_no: infoObj.order_no,
            target_user_name: infoObj.target_user_name,
            target_address: infoObj.address_detail,
            target_description: infoObj.remark,
            pay_account: infoObj.transfer_remittance_account,
            bank_account_name: infoObj.account_name,
            bank_name: infoObj.bank_of_deposit,
            pay_type: infoObj.settle_mode_name,
            client: infoObj.purchaser_name,
            phone: infoObj.target_user_phone,
            order_total_length: (infoObj.total_number / 100).toString(),
            order_total_price: (
                infoObj.bill_total_sale_price / 100
            ).toString(),
            total_weight_error_discount: (
                infoObj.total_weight_error_discount / 100
            ).toString(),
            order_total_num: infoObj.total_number.toString(),
            qrcode: `${PAY_H5_CODE_URL}?sale_order_no=${infoObj.order_no}`,
            order_total_weight: (infoObj.total_weight / 1000).toString(),
            estimate_amount: (infoObj.estimate_amount / 100).toString(),
            total_sale_price: (infoObj.total_sale_price / 100).toString(),
            show_total_sale_price: true,
            show_total_weight_error_discount: true,
            actual_amount: (infoObj.actual_amount / 100).toString(),
            wait_pay_amount: (infoObj.wait_pay_amount / 100).toString(),
            order_total_weight_error: (
                infoObj.total_weight_error / 1000
            ).toString(),
        };
        const res = await payFetch(query)
        if (res.data) {
            console.log(res.data.base64)
            setShowSide(false)
            setTitle('查看销售码单')
            setPicUrl(res.data.base64)
        }
    }


    //确认交易
    const { fetchData: payOneFetch } = orderPaymentorderPaymentSubmission()
    const { fetchData: payTwoFetch } = orderPaymentpreCollectOrderorderPaymentSubmission()
    const handsurePay = (obj) => {
        let arr: any = []
        // if (obj.status !== 10) {
        arr = payList.filter(item => {
            return item.checked
        })
        if (!arr.length) {
            Taro.showToast({
                title: '请选择后再提交',
                icon: 'error'
            })
            return false
        }

        Taro.showModal({
            content: "确定交易吗？",
            confirmText: "确认",
            cancelText: "取消",
            success: async function (res) {
                if (res.confirm) {
                    Taro.showLoading({
                        title: '请稍等...',
                        mask: true
                    })
                    let restult = await (obj.status !== 10 ? payOneFetch({ id: Number(obj.should_collect_order_id), payment_method: Number(arr[0]?.id) }) : payTwoFetch({ id: Number(obj.pre_collect_order_id), payment_method: Number(arr[0]?.id) }))
                    if (restult?.msg === 'success') {
                        Taro.showToast({
                            title: '交易成功'
                        })
                        Taro.hideLoading()
                        setShowPay(false)
                        getDetail()
                    } else {
                        Taro.hideLoading()
                        Taro.showToast({
                            title: restult?.msg,
                            icon: 'error'
                        })
                    }
                }

            }
        })

        // }
    }

    //显示支付
    const [showPay, setShowPay] = useState(false)
    //显示线下汇款
    const [showOffline, setShowOffine] = useState(false)
    //选择地址
    const handSelect = (obj) => {
        if (receivingStatus === 1 || (infoObj.status === 8 || infoObj.status === 9 || infoObj.status === 4 || infoObj.status === 5 || infoObj.status === 11 || infoObj.status === 3)) {
            alert.error('不允许更改')
            return false
        }
        Taro.navigateTo({
            url: '/pages/addressManager/index?orderId=' + obj.id + '&purchaser_id=' + obj.purchaser_id
        })
    }

    //申请退货
    const handApplyGood = () => {
        if (infoObj.av_return_product.length == 0) {
            return alert.error('暂无货物退')
        } else {
            Taro.navigateTo({
                url: '/pages/applyGoods/index?orderId=' + infoObj.id
            })
            setShowMore(false)
        }
    }

    //申请退款
    const handApplyMoney = () => {

        Taro.navigateTo({
            url: '/pages/applyMoney/index?orderId=' + infoObj.id
        })
        setShowMore(false)
    }


    //确认收货
    const { fetchData: receveFetch } = mpsaleOrderreceive()
    const handSureGoods = async () => {
        Taro.showModal({
            content: "确认收货吗？",
            confirmText: "确认",
            cancelText: "取消",
            success: async function (res) {
                if (res.confirm) {
                    Taro.showLoading({
                        title: '请稍等...',
                        mask: true
                    })
                    const res = await receveFetch({ sale_order_id: Number(infoObj.id) })
                    if (res?.msg === 'success') {
                        Taro.showToast({
                            title: '成功'
                        })
                        Taro.hideLoading()
                        setShowMore(false)
                        getDetail()
                    } else {
                        Taro.hideLoading()
                        Taro.showToast({
                            title: res?.msg,
                            icon: 'error'
                        })
                    }
                }

            }
        })
    }

    const onChange = (e) => {
        setInfoObj((val) => ({ ...val, remark: e }))
    }

    useEffect(() => {
        setInfoObj(infoObj)
    }, [infoObj])
    const showRemarkFont = useMemo(() => {
        if (infoObj.status === 10 || infoObj.status == 0 || infoObj.status == 1 || infoObj.status == 2 || infoObj.status == 7) {
            return `${'填写/修改备注'} >`
        } else {
            return ''
        }
    }, [infoObj])

    const BottomBtnsRef = useRef<any>()
    const [showOther, setshowOther] = useState(false)
    useMemo(() => {
        Taro.nextTick(() => {
            if (BottomBtnsRef.current?.itemNums >= 4) {
                setshowOther(true)
                return true
            } else {
                setshowOther(false)
                return false
            }
        })
    }, [infoObj])


    return (
        <View className={styles.mainBox}>
            {(infoObj?.status != 10 && <OrderState orderInfo={infoObj} />)}
            {
                infoObj.status === 10 && <AdvanceOrderState orderInfo={infoObj} onRefresh={() => refresh()} />
            }
            <AddressDetailBox
                navSelect={(obj) => handSelect(obj)}
                obj={infoObj}
                receivingStatus={receivingStatus}
                onReceivingStatus={(e, value) => onReceivingStatus(e, value)}
            ></AddressDetailBox>
            <DefaultBox
                showMode={true}
                title={'客户信息'}
                modeName={infoObj.sale_mode_name}
            >
                <View className={styles.pussBox}>
                    <View className={styles.pussName}>{infoObj.purchaser_name}</View>
                    <View className={styles.pussPhone}>{infoObj.purchaser_phone}</View>
                </View>
            </DefaultBox>
            <View className={styles.total}> {infoObj.total_fabrics} 种面料，{infoObj.total_colors} 个颜色，共 {infoObj.sale_mode === 0 ? infoObj.total_number : infoObj.total_number / 100} {infoObj.sale_mode === 0 ? '条' : 'm'}</View>
            <View className={styles.productBox}>
                <GoodsItem list={infoObj?.product_list} obj={infoObj}></GoodsItem>
                <View className={styles.flexMoney}>
                    <View className={styles.flexTotalBox}>
                        <View className={styles.totalFont}>合计金额</View>
                        <IconFont name={'icon-tishi'} size={28} ></IconFont>
                    </View>
                    <View className={styles.shoudPay}>¥{formatPriceDiv(infoObj.bill_total_sale_price)}</View>
                </View>
                <View className={styles.flexMoney}>
                    <View className={styles.flexTotalBox}>
                        <View className={styles.totalFont}>实付金额</View>
                        <IconFont name={'icon-tishi'} size={28} ></IconFont>
                    </View>
                    <View className={styles.shoudPay}>¥{formatPriceDiv(infoObj.actual_amount)}</View>
                </View>
                <View className={styles.flexMoney}>
                    <View className={styles.flexTotalBox}>
                        <View className={styles.totalFont}>待付金额</View>
                        {/* <View className={classnames('iconfont', 'icon-tishi', styles.tishi)}></View> */}
                        <IconFont name={'icon-tishi'} size={28} ></IconFont>
                    </View>
                    <View className={styles.shoudPay}>¥{formatPriceDiv(infoObj.wait_pay_amount)}</View>
                </View>
            </View>
            <DefaultBox title={'订单信息'}>
                {
                    orderMsg.map((item, index) => {
                        return (
                            <View className={styles.detailBox} key={index}>
                                <View className={styles.detailFont}>
                                    {item.leftTitle}
                                </View>
                                <View className={styles.detailRightFlex}>
                                    <View className={styles.detailRight}>{item.rightTitle}</View>
                                    {item.showBtn && <View className={styles.detailBtn} onClick={() => clipboardData()}>复制</View>}
                                </View>

                            </View>
                        )
                    })
                }

            </DefaultBox>
            <DefaultBox title={'备注信息'} showMode={true} modeName={showRemarkFont} clickNode={() => setShowDesc(showRemarkFont != '' ? true : false)}>
                <View className={styles.remarkFont}>{infoObj.remark === '' ? '暂无' : infoObj.remark}</View>
            </DefaultBox>

            <Popup show={showDesc} title={'填写/编辑备注'} showTitle={true} onClose={() => setShowDesc(false)}>
                <View style={{ margin: '24rpx' }}>
                    <Remark
                        //  onSave={(e) => getRemark(e)}
                        onChange={(e) => onChange(e)}
                        defaultValue={infoObj.remark} />
                    <View className={styles.order_save_address} onClick={() => getRemark()}>保存</View>
                </View>

            </Popup>
            <View className={styles.safeBottom}></View>
            <View className={styles.bottomBox}>
                {
                    showOther &&
                    <>
                        {
                            !showMore && <View className={styles.moreFontBox}> <View className={styles.moreFont} onClick={() => setShowMore(true)}>更多</View></View>
                        }
                        {
                            showMore && <View className={styles.moreFontBox}>  <View className={styles.moreFont} onClick={() => setShowMore(false)}>关闭</View></View>
                        }
                        {
                            showMore && <View className={styles.posssBox}>
                                <BottomApply
                                    obj={infoObj}
                                    goodsObj={infoObj}
                                    handApplyGoods={() => handApplyGood?.()}
                                    handApplyMoney={() => handApplyMoney?.()}
                                ></BottomApply>
                            </View>
                        }
                    </>
                }


                <BottomBtns
                    ref={BottomBtnsRef}
                    showDetail
                    goodsObj={infoObj}
                    obj={infoObj}
                    showTuiGoods
                    cancle={(e) => cancle?.(e, infoObj)}
                    nextBuy={(e) => nextBuy?.(e, infoObj)}
                    toPay={(e) => toPay?.(e, infoObj)}
                    handSureGoods={() => handSureGoods?.()}
                    handApplyGoods={() => handApplyGood?.()}
                    handApplyMoney={() => handApplyMoney?.()}
                ></BottomBtns>
            </View>
            <PayPopup
                list={payList}
                obj={infoObj}
                showPopup={showPay}
                popupClose={() => setShowPay(false)}
                clickItem={(infoObj) => clickItem(infoObj)}
                handsurePay={(infoObj) => handsurePay(infoObj)}
                showSide={showSide}
                title={title}
                picUrl={picUrl}
            ></PayPopup>
            <OfflinePay showKong={false} show={showOffline} onClose={() => setShowOffine(false)} offlineInfo={infoObj}></OfflinePay>
        </View >
    )
}



//卡片盒子元素
interface Obs {
    title?: string,
    modeName?: string,
    showMode?: boolean,
    children?: ReactNode,
    clickNode?: () => void
}

const DefaultBox = memo((props: Obs) => {
    const {
        title = '标题',
        modeName = '大货',
        showMode = false,
        children,
        clickNode
    } = props

    return (
        <View className={styles.defaltBox}>
            <View className={styles.titleBox}>
                <View className={styles.title}>{title}</View>
                {
                    showMode && <View className={styles.modeName} onClick={() => clickNode?.()}>{modeName}</View>
                }
            </View>
            <View className={styles.modeLine}></View>
            {children}
        </View>
    )
})


//产品商品元素
interface PropGoods {
    // item?: {
    //     code?: string | number
    // }
    list: any[],
    obj: {
        sale_mode?: number | string
    },
}
const GoodsItem = memo((porps: PropGoods) => {
    const { list = [], obj = {} } = porps
    return (
        <>
            {
                list.map((item, index) => {
                    return (
                        <View className={styles.goodsBox} key={index}>
                            <View className={styles.goodsProduct}>{item.code}# {item.name}</View>
                            <View className={styles.goodsLine}></View>
                            {
                                item.product_colors.map((it, inx) => {
                                    return (
                                        <View className={styles.itemGoods}>
                                            <View className={styles.itemPic} style={{ backgroundColor: `rgb(${it?.rgb?.r} ${it?.rgb?.g} ${it?.rgb?.b})` }}></View>
                                            <View className={styles.itemRight}>
                                                <View className={styles.item_right_top}>
                                                    <View className={styles.itemName}>{it.code}# {it.name}</View>
                                                    <View className={styles.itemNums}>x{obj?.sale_mode === 0 ? it.roll : it.length / 100}{obj?.sale_mode === 0 ? '条' : 'm'}</View>
                                                </View>
                                                <View className={styles.item_right_Bottom}>
                                                    <View className={styles.itemMoney}>¥{it.sale_price / 100}/{obj?.sale_mode === 0 ? '条' : 'm'}</View>
                                                    <View className={styles.itemMoneyOne}>¥{formatPriceDiv(it.total_sale_price)}</View>
                                                </View>
                                            </View>
                                        </View>
                                    )
                                })
                            }
                        </View>
                    )
                })
            }
        </>

    )
})

